@@ -1,7 +1,7 @@
 import os
 import uuid
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 ROOT = os.path.dirname(os.path.abspath(__file__))
 QUEUE_DIR = os.path.join(ROOT, f'queue_manager')
@@ -11,7 +11,7 @@ MQTT_BROKER = os.getenv('MQTT_BROKER', 'epione-demo.inria.fr')
 MQTT_BROKER_PORT = int(os.getenv('MQTT_BROKER_PORT', 80))
 
 UPLOADS_URL = os.getenv('UPLOADS_URL', 'https://epione-demo.inria.fr/fedbiomed/upload/')
-CLIENT_ID = os.getenv('CLIENT_ID', str(uuid.UUID(int=uuid.getnode())))
+CLIENT_ID = os.getenv('CLIENT_ID', 'client_' + str(uuid.UUID(int=uuid.getnode())))
 
 # ========= PATCH MNIST Bug torchvision 0.9.0 ===================
 # https://github.com/pytorch/vision/issues/1938
