@@ -49,6 +49,14 @@ def run_model_training(msg):
         else:
             model = Model
 
+        # Load model initialization parameters
+        try:
+            from torch.utils.model_zoo import load_url
+            model_params = load_url(msg['initial_params'])
+            model.load_state_dict(model_params)
+        except KeyError:
+            pass
+
         # Run the training routine
         results = {}
 
@@ -59,6 +67,7 @@ def run_model_training(msg):
             print(e)
             training_routine(model, **training_kwargs)
 
+        results['job_id'] = msg['job_id']
         results['model_params'] = model.state_dict()
         results['history'] = logger.history
         results['client_id'] = CLIENT_ID
